# MultiTargetVectorJoinWeightsValue


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from arthur_observability_sdk._generated.models.multi_target_vector_join_weights_value import MultiTargetVectorJoinWeightsValue

# TODO update the JSON string below
json = "{}"
# create an instance of MultiTargetVectorJoinWeightsValue from a JSON string
multi_target_vector_join_weights_value_instance = MultiTargetVectorJoinWeightsValue.from_json(json)
# print the JSON string representation of the object
print(MultiTargetVectorJoinWeightsValue.to_json())

# convert the object into a dict
multi_target_vector_join_weights_value_dict = multi_target_vector_join_weights_value_instance.to_dict()
# create an instance of MultiTargetVectorJoinWeightsValue from a dict
multi_target_vector_join_weights_value_from_dict = MultiTargetVectorJoinWeightsValue.from_dict(multi_target_vector_join_weights_value_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


